@@ -26,7 +26,7 @@ def create_task(branch, integration_id,task_name, hchighered_contentPath):
                                     "higher_ed_msp", "setup", "demo", "poc", "example"
                                 ],
                                 "taskOptions": {
-                                    "pythonAdditionalPackages": "requests",
+                                    "pythonAdditionalPackages": "requests morphcp",
                                     "username": None,
                                     "password": None,
                                     "passwordHash": None,
